
. (2017-05-19)
###############

Changes since 0.4.13 (2016-12-12).

New Features
$$$$$$$$$$$$$

* Closed `#439 <https://bitbucket.org/biocommons/hgvs/issues/439/>`_: Add method to explicitly close database connections [`5a876fd2d1ec <https://bitbucket.org/biocommons/hgvs/commits/5a876fd2d1ec>`_]
